@@ -48,6 +48,7 @@ overrides = T.unlines
  , "# It is useful to expose these class structs when deriving new types"
  , "set-attr Gtk/WidgetClass haskell-gi-force-visible 1"
  , "set-attr Gtk/ContainerClass haskell-gi-force-visible 1"
+ , "set-attr Gtk/ActionableInterface haskell-gi-force-visible 1"
  , ""
  , "# Not properly annotated in older versions of gtk"
  , "set-attr Gtk/CellLayoutDataFunc/@parameters/data closure 4"
@@ -1442,6 +1443,7 @@ modules =  [ "GI.Gtk.Config"
  , "GI.Gtk.Structs.AccelGroupEntry"
  , "GI.Gtk.Structs.AccelKey"
  , "GI.Gtk.Structs.ActionEntry"
+ , "GI.Gtk.Structs.ActionableInterface"
  , "GI.Gtk.Structs.BindingArg"
  , "GI.Gtk.Structs.BindingEntry"
  , "GI.Gtk.Structs.BindingSet"
