@@ -350,6 +350,7 @@ instance AttrInfo ScrollableHadjustmentPropertyInfo where
     type AttrOrigin ScrollableHadjustmentPropertyInfo = Scrollable
     attrGet = getScrollableHadjustment
     attrSet = setScrollableHadjustment
+    attrPut = undefined
     attrTransfer _ v = do
         unsafeCastTo Gtk.Adjustment.Adjustment v
     attrConstruct = constructScrollableHadjustment
@@ -392,7 +393,7 @@ constructScrollableHscrollPolicy val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data ScrollableHscrollPolicyPropertyInfo
 instance AttrInfo ScrollableHscrollPolicyPropertyInfo where
-    type AttrAllowedOps ScrollableHscrollPolicyPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps ScrollableHscrollPolicyPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint ScrollableHscrollPolicyPropertyInfo = IsScrollable
     type AttrSetTypeConstraint ScrollableHscrollPolicyPropertyInfo = (~) Gtk.Enums.ScrollablePolicy
     type AttrTransferTypeConstraint ScrollableHscrollPolicyPropertyInfo = (~) Gtk.Enums.ScrollablePolicy
@@ -402,6 +403,7 @@ instance AttrInfo ScrollableHscrollPolicyPropertyInfo where
     type AttrOrigin ScrollableHscrollPolicyPropertyInfo = Scrollable
     attrGet = getScrollableHscrollPolicy
     attrSet = setScrollableHscrollPolicy
+    attrPut = setScrollableHscrollPolicy
     attrTransfer _ v = do
         return v
     attrConstruct = constructScrollableHscrollPolicy
@@ -463,6 +465,7 @@ instance AttrInfo ScrollableVadjustmentPropertyInfo where
     type AttrOrigin ScrollableVadjustmentPropertyInfo = Scrollable
     attrGet = getScrollableVadjustment
     attrSet = setScrollableVadjustment
+    attrPut = undefined
     attrTransfer _ v = do
         unsafeCastTo Gtk.Adjustment.Adjustment v
     attrConstruct = constructScrollableVadjustment
@@ -505,7 +508,7 @@ constructScrollableVscrollPolicy val = MIO.liftIO $ do
 #if defined(ENABLE_OVERLOADING)
 data ScrollableVscrollPolicyPropertyInfo
 instance AttrInfo ScrollableVscrollPolicyPropertyInfo where
-    type AttrAllowedOps ScrollableVscrollPolicyPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
+    type AttrAllowedOps ScrollableVscrollPolicyPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet, 'AttrPut]
     type AttrBaseTypeConstraint ScrollableVscrollPolicyPropertyInfo = IsScrollable
     type AttrSetTypeConstraint ScrollableVscrollPolicyPropertyInfo = (~) Gtk.Enums.ScrollablePolicy
     type AttrTransferTypeConstraint ScrollableVscrollPolicyPropertyInfo = (~) Gtk.Enums.ScrollablePolicy
@@ -515,6 +518,7 @@ instance AttrInfo ScrollableVscrollPolicyPropertyInfo where
     type AttrOrigin ScrollableVscrollPolicyPropertyInfo = Scrollable
     attrGet = getScrollableVscrollPolicy
     attrSet = setScrollableVscrollPolicy
+    attrPut = setScrollableVscrollPolicy
     attrTransfer _ v = do
         return v
     attrConstruct = constructScrollableVscrollPolicy
